function bookfigprint(figFileName,imagSize,fig)
% BOOKFIGPRINT Print the given figure in the proper format for the book
%
% Usage:
%
%   bookfigprint(figFileName,[imagSize],[fig])
%
%   figFileName is the name of the file to create
%   [imagSize] is the size of the image in inches. By default we use full
%   8.5 by 11.
%   [fig] will print the specified figure number.  By default the current
%   figure will be printed.
%
%

% Version 1.1 Fixed to handle images. annotations still do not get picked
% up.  Annotations seem to have changed over the releases so I am not
% coding to handle them.
% Version 1.0 Initial release

%   Copyright 2009 The MathWorks, Inc. 

%% Generate the full path name to where we want the file
% Get Path to where we want the file to be
x=bookpathinfo;

% if the extention is specified just remove it.  This allows the user to
% not need to specify it and we will put it on automatically for them.
figFileName = regexprep(figFileName,'.eps','');

file = [x.eps,filesep,figFileName,'.eps'];

%% Handle if the user did not specify the figure to print by using the
% current figure
if ~exist('fig','var')
    fig = gcf;
end

%% Set the PaperPosition on the figure so that all figures are the same
%   PaperUnits = inches
%	PaperOrientation = portrait
%	PaperPosition = [0.25 2.5 8 6]
%	PaperPositionMode = manual
%	PaperSize = [8.5 11]
%	PaperType = usletter

% Use size specified
if exist('imagSize','var')
    paperPosition = [0.5, 2.5, imagSize(1),imagSize(2)];
else
    paperPosition = [0.25,2.5,8,6];
end

set(fig,'PaperUnits','inches');
set(fig,'PaperOrientation','portrait');
set(fig,'PaperPosition',paperPosition);
set(fig,'PaperSize',[8.5,11]);

%% Force Fonts Size and Style to be the same based on image size
% nfont=1 for figures that will be about 5 inches wide, and 2 for
% figures that will be about 2.5 inches wide.  The latter are
% normally figures that will be combined to make a single figure.
if paperPosition(3)>3
    nfont = 1;
else
    nfont = 2;
end
xaxisfont=[18,16];
xtextfont=[14,16];
xmarkersize=[10,10];
xlinesize=[3,3];
axisfont=xaxisfont(nfont);
textfont=xtextfont(nfont);
markersize=xmarkersize(nfont);
linesize=xlinesize(nfont);

figChildren = get(fig,'Children');

for idx = 1:length(figChildren)
    switch get(figChildren(idx),'Type') % This is an axis
        case 'axes'
            setAxis(figChildren(idx));
        case 'uicontrol'
            setText(figChildren(idx));
        otherwise
            error('Found Figure Child Object that is not an axes, legend, or uicontrol');
    end
end

    function setAxis(hAxis)
        % Currently this does not handle Annotations yet
        set(hAxis,'FontName','Times');
        set(hAxis,'FontSize',axisfont);
        set(hAxis,'FontAngle','normal');
        set(hAxis,'FontWeight','bold');
        set(hAxis,'LineStyleOrder','-|--|-.|:');
        setText(get(hAxis,'XLabel'));
        setText(get(hAxis,'YLabel'));
        axisChildren = get(hAxis,'children');
        fixChildren(axisChildren);
    end
    function fixChildren(axisChildren)
        for idxAxisChild = 1:length(axisChildren)
            switch get(axisChildren(idxAxisChild),'Type')
                case 'line'
                    set(axisChildren(idxAxisChild),'MarkerSize',markersize);
                    set(axisChildren(idxAxisChild),'LineWidth',linesize);
                case 'text'
                    setText(axisChildren(idxAxisChild));
                case 'image'
                % Nothing in image that we need to handle 
                case 'light'
                case 'patch'
                case 'rectangle'
                case 'surface'
                case 'hggroup'
                    fixChildren(get(axisChildren(idxAxisChild),'children'));
                otherwise
                    error('Unhandled HG object of type: %s',get(axisChildren(idxAxisChild),'Type'));
            end
        end
    
    end
    function setText(hText)
        if isfield(hText,'Fontname'); set(hText,'FontName','Times'); end
        if isfield(hText,'FontSize'); set(hText,'FontSize',textfont); end
        if isfield(hText,'FontAngle'); set(hText,'FontAngle','normal'); end
        if isfield(hText,'FontWeight'); set(hText,'FontWeight','normal'); end
    end
%
% Set the colors and line styles
%

%% Finally print the figure to the location using EPS 300dpi
% -loose     % Use Figure's PaperPosition as PostScript BoundingBox
% -r300      % Prints using 300dpi resolution
%  Chuck changed from -deps to -depsc for cases where color is needed
print('-depsc','-loose','-r300',sprintf('-f%d',fig),file);

end