function [x,y,yedge]=lensshape(rr1,rr2,yedgetarget,thtarget)
%% LENSSHAPE Computes curves to be used to draw lenses on plots
%
% SYNTAX:
% [x,y]=lensshape(rr1,rr2,yedge,th);
%
% Returns x and y as the coordinates of the outline of a lens with radius
% of curvature rr1 on the first surface and rr2 on the second, with a
% semi-diameter of yedge, and  thickness, th.  Units can be any length
% unit provided they are  consistent.  Radius of curvature is defined as
% positive for surfaces that  are convex to the left.  The axial thickness
% will be th if that leaves the edge thickness greater than zero.
% Otherwise, th will be the edge thickness
%
% by Chuck DiMarzio
%    Northeastern University
%    December 2008
%
% Example;
%        r1p=10;r2p=10;s=50;
%        [x,y,yedge]=lensshape(r1p,r2p,5,1);
%        plot(xl+x*s/yedge,yl+y*s/yedge);
%
%     This example plots a biconvex positive lens with radii of curavature
%     of 10 units and a semi-diameter of 5 units.  After the x,y
%     coordinates are generated, the lens is rescaled to have a radius of
%     50 plot units.  For example, s could be generated by AXIS data to be
%     a fraction of the plot area.
%
%
%  !! This file may be copied, used, or modified for educational and
%  !! research purposes provided that this header information is not
%  !! removed or altered, and provided that the book is cited in 
%  !! publications, as DiMarzio, Charles A., Optics for Engineers, 
%  !! CRC Press, Boca Raton, FL, 2011.
%  !! http://www.crcpress.com
%  !! Other distribution is prohibited without permission.
%
yedge=min([abs(rr1)*0.7,abs(rr2)*0.7,yedgetarget]);
yy=yedge*[-1:0.1:1];
if(abs(rr1)==Inf);
  xedge1=-thtarget/2;
else
  xedge1=-thtarget/2+rr1.*(1-sqrt(1-yedge^2/rr1.^2));
end;
if(abs(rr2)==Inf);
  xedge2=thtarget/2;
else
  xedge2=thtarget/2+rr2.*(1-sqrt(1-yedge.^2/rr2.^2));
end;
xtest=xedge2-xedge1;  % Check for negative edge
if (xtest>0); 
  th=thtarget;
else
  th=thtarget-xtest;  % xtest is negative... increase the thickness
end; 
if(abs(rr1)==Inf);
  x1=-th/2*ones(size(yy));
else
  x1=-th/2+rr1.*(1-sqrt(1-yy.^2/rr1.^2));
end;
if(abs(rr2)==Inf);
  x2=th/2*ones(size(yy));
else
  x2=th/2+rr2.*(1-sqrt(1-yy.^2/rr2.^2));
end;
x=[x1,fliplr(x2),x1(1)];
y=[yy,fliplr(yy),yy(1)];
