function [ls,qmin]=coddington(p,q,f,h,n)
%
% CODDINGTON computes the longitudinal spherical aberration for a simple
%            lens. 
%
% SYNTAX:
%  [ls,qmin]=coddington(p,q,f,h,n);
%         ls=coddington(p,q,f,h,n);
%  [ls,qmin]=coddington(p,[],f,h,n);
%         ls=coddington(p,[],f,h,n);
%
%  where
%  p = (sprime-s)/(sprime+s)  Coddington position factor, s=object distance
%                                                 sprime=image distance
%  q = (r2+r1)/(r2-r1) Coddington Shape factor. r1 and r2 positive for lens
%  surfacees convex to air.  In other words, a biconvex lens has both
%  r1 and r2 positive. 
%  q=[] to select optimal q
%  h is the height of the ray
%  f is the focal length of the lens
%  n is the index of refraction of the glass
%
%  ls is the longitudinal spherical aberration, 
%     ls = 1/sprime(0) - 1/sprime(h)
%  qmin is the value of q that produces minimal spherical aberration
%
% p,q,h,f, and n must all be scalars, or have the same dimensions
%
%
%  EXAMPLE:
%
%  An f/2.8 biconvex lens used in a 4-f imaging system (see text Chapter 5)
%  with an index of refraction 1.52 and f=10 cm.
%
%  >> f=10;s=2*f;sprime=1/(1/f-1/s);fnumber=2.8;p=(sprime-s)/(sprime+s);
%  >> sprime
%  sprime =
%      20
%  >> [ls,qmin]=coddington(p,0,f,f/fnumber/2,1.52)
%  ls =
%      0.0034
%  qmin =
%       0
%  >> sprime_h=1/(1/sprime-ls)
%  sprime_h =
%     21.4619
%  >> 
%  The marginal focus is 1.46 cm beyond the paraxial focus.  This is a
%  serious aberration, which is not surprising at f/2.8.
%
%  by Chuck DiMarzio
%     Northeastern University
%     April 2009
%
%
%  !! This file may be copied, used, or modified for educational and
%  !! research purposes provided that this header information is not
%  !! removed or altered, and provided that the book is cited in 
%  !! publications, as DiMarzio, Charles A., Optics for Engineers, 
%  !! CRC Press, Boca Raton, FL, 2011.
%  !! http://www.crcpress.com
%  !! Other distribution is prohibited without permission.
%
%
qmin=-2*(n.^2-1)./(n+2).*p;  % q for this p to give minimum aberration
if(numel(q)==0);qq=qmin;else qq=q;end; 
ls=h.^2./8./f.^3./n./(n-1).*...
    ((n+2)./(n-1).*qq.^2 + 4*(n+1).*p.*qq+...
     (3*n+2).*(n-1).*p.^2+n.^3./(n-1));  % Longitudinal spherical aberration
