function [s1,s2]=raysphere(p0,pc,v,r)
%% RAYSPHERE calculates the intersection of a ray and a sphere
%
%   SYNTAX;
%     [s1,s2]=raysphere(p0,pc,v,r)
%
%      where p0 is a vector of the x,y,z coordinates of the ray origin
%            v  is a unit vector in the direction of the ray
%            pc is a vector of the x,y,z coordinates of the sphere center
%            r  is the radius
%
%  A vector to any point on the sphere is p, where (p-pc)'*(p-pc)=r^2
%  The vector to a point on the ray at a distance s from p0 is p = p0+s*v
% 
%  s1 and s2 are the two solutions for s.
%  if only one solution exists, s1=s2.
%  if no solutions exist, s1=s2=NaN
%  Error in dimensions of input returns s1=s2=Inf
%
% Choose the desired solution and compute the point of intersection
%
% Example:
%
% p0=[-5,0,0]';pc=[0,1,0]';v=[1,0,0]';r=2;
% [s1,s2]=raysphere(p0,pc,v,r)
% s1 =
%     3.2679
% s2 =
%     6.7321
% p1=p0+s1*v
% p1 =
%    -1.7321
%          0
%          0
%
%
% See Also;
%      ABDEMO, PCLENS, COMA, ASTIG
%
%% by Chuck DiMarzio
%    Northeasteren University
%    April 2009
%
%
%  !! This file may be copied, used, or modified for educational and
%  !! research purposes provided that this header information is not
%  !! removed or altered, and provided that the book is cited in 
%  !! publications, as DiMarzio, Charles A., Optics for Engineers, 
%  !! CRC Press, Boca Raton, FL, 2011.
%  !! http://www.crcpress.com
%  !! Other distribution is prohibited without permission.
%
% 
%% Test that all dimensions are correct
if((size(p0)==[3,1])&(size(pc)==[3,1])&(size(v)==[3,1])&(size(r)==[1,1]));
% Make sure v is a unit vector  
v=v/sqrt(v'*v);
  b=-pc'*v+p0'*v-v'*pc+v'*p0;
  c=pc'*pc-pc'*p0-p0'*pc+p0'*p0-r^2;

% Solve the quadratic equation s^2 + b*s + c = 0 with solutions
% s = (-b (+/-) sqrt(b^2-4*c))/2

  q2=b^2-4*c;
  if(q2<0);
    s1=0/0;
    s2=0/0;
  else
    q=sqrt(q2);
    s1=(-b-q)/2;
    s2=(-b+q)/2;
  end;
else
  s1=Inf;s2=Inf;
end;
