%% FRINGES Generates synthetic fringe patterns
%
% by Chuck DiMarzio
%    Northeastern University
%    May 2009
%
%
%  !! This file may be copied, used, or modified for educational and
%  !! research purposes provided that this header information is not
%  !! removed or altered, and provided that the book is cited in 
%  !! publications, as DiMarzio, Charles A., Optics for Engineers, 
%  !! CRC Press, Boca Raton, FL, 2011.
%  !! http://www.crcpress.com
%  !! Other distribution is prohibited without permission.
%
%% Equation
% $$E = E_{ref} + E_{sig} $$
% $$ I = E E^* $$
%
%% Coordinates
xx=(-1:0.01:1);
[x1,y1]=meshgrid(xx,xx); % x,y rectangular coordinates
rsq=x1.^2+y1.^2;         % r = radial coordinate
%% Parameters
lambda=632.8; % wavelength in nm
bumpheight=2*lambda; % Represents a bump on a mirror
smallbumpheight=lambda/5; % 
bumpwidth=0.3;  % width of the bump in x1,y1
bumpcenter=[0.15,0.4];
%
% Delta is twice the bumpheight because the light reflects from the mirror
% and thus the path length change is twice the change in the surface
% position.  The bump has a Gaussian shape.
%
relrad=((x1-bumpcenter(1)).^2+(y1-bumpcenter(2)).^2)/(bumpwidth/2).^2;
%% Optical Path Length for a bump and a small bump
Delta_bump=2*bumpheight*exp(-relrad); 
Delta_smallbump=2*smallbumpheight*exp(-relrad); 

%% Reference Wave at z=0, t = 0
Eref=zeros(size(x1));
Eref(rsq<1)=1;   % Plane wave in circular aperture

%% Tilted plane-wave signal, with tilt coefficient a1
% $$ \Delta_{tilt} = a1 x1 $$
% $$ \Delta_{tilt} = 8 \lambda $$ at $$ x1==2 $$
a1=8*lambda/2;
Esigflat=exp(1i*2*pi/lambda*a1*x1);
%
%
E = Eref+Esigflat;
I = (abs(E)).^2;
fig1=figure;imagesc(xx,xx,I);axis image;colormap(flipud(gray));axis off;

%% Tilted plane--wave signal with bumps
Esig=Esigflat.*exp(1i*2*pi/lambda*Delta_bump);
E = Eref+Esig;
I = (abs(E)).^2;
fig2=figure;imagesc(xx,xx,I);axis image;colormap(flipud(gray));axis off;

Esig=Esigflat.*exp(1i*2*pi/lambda*Delta_smallbump);
E = Eref+Esig;
I = (abs(E)).^2;
fig3=figure;imagesc(xx,xx,I);axis image;colormap(flipud(gray));axis off;

%% Curved, spherical signal wavefront
% $$ Delta_f = b1 \rho^2$$
% $$ Delta_f = 4 \lambda $$ at $$ x_1=1$$
b1=4*lambda;
Esigsph=exp(1i*2*pi/lambda*b1*rsq);

E = Eref+Esigsph;
I = (abs(E)).^2;
fig4=figure;imagesc(xx,xx,I);axis image;colormap(flipud(gray));axis off;

%% Curved signal wave with bumps
Esig=Esigsph.*exp(1i*2*pi/lambda*Delta_bump);
E = Eref+Esig;
I = (abs(E)).^2;
fig5=figure;imagesc(xx,xx,I);axis image;colormap(flipud(gray));axis off;

Esig=Esigsph.*exp(1i*2*pi/lambda*Delta_smallbump);
E = Eref+Esig;
I = (abs(E)).^2;
fig6=figure;imagesc(xx,xx,I);axis image;colormap(flipud(gray));axis off;

