function [ras,rap,tas,tap]=fresnel(thetad,n)
%%  FRESNEL computes Fresnel Reflection and Transmission
%
%  SYNTAX:
%   [ras,rap,tas,tap]=fresnel(theta,n);
%
%   where ras,rap,tas,tap are Reflection and Transmission
%         coeffcients for Amplitude for S and P polarization.
%         identified as rho and tau in text Chapter 6.
%   Input theta is in degrees, n is index of refracton, which may
%         be complex.
%
%  EXAMPLE:
%
% (1) S polarized reflection of typical glass for varying angle
%
%   >> thetad=[0:10:90];
%   >> [ras,rap,tas,tap]=fresnel(thetad,1.5);
%   >> RS=abs(ras).^2
%   RS =
%       0.0400    0.0417    0.0471    0.0578    0.0772    0.1120  ...
%               0.1766    0.2996    0.5386    1.0000
%   >> 
%  by Chuck DiMarzio
%     Northeastern University
%     September, 2001
%     Based on FORTRAN code by C. D. and Mike Healy, 1991
%
% (2) S polarized reflection at normal incidence for different materials
%
%  >> n=[1.3,1.5,2.4,4];
%  >> [ras,rap,tas,tap]=fresnel(0,n);
%  >> RS=abs(ras).^2
%  RS =
%      0.0170    0.0400    0.1696    0.3600
%  >> 
%
%  !! This file may be copied, used, or modified for educational and
%  !! research purposes provided that this header information is not
%  !! removed or altered, and provided that the book is cited in 
%  !! publications, as DiMarzio, Charles A., Optics for Engineers, 
%  !! CRC Press, Boca Raton, FL, 2011.
%  !! http://www.crcpress.com
%  !! Other distribution is prohibited without permission.
%
%% Convert to radians and compute amplitude coefficients
theta=thetad*pi/180;
%     amplitude reflection coefficient s polarized
ras=(cos(theta)-sqrt(n.^2-(sin(theta)).^2))./...
       (cos(theta)+sqrt(n.^2-(sin(theta)).^2));
%     amplitude reflection coefficient p polarized
rap=-( sqrt(n.^2-(sin(theta)).^2) -n.^2.*cos(theta) )./...
      ( sqrt(n.^2-(sin(theta)).^2) +n.^2.*cos(theta) );
%     amplitude transmission coefficient s polarized
tas=1.+ras;
%     amplitude transmission coefficient p polarized
tap=(1.+rap)./n;

